@@ -1,5 +1,5 @@
 #!perl
-# Copyright 2018 Jeffrey Kegler
+# Copyright 2022 Jeffrey Kegler
 # This file is part of Marpa::R2.  Marpa::R2 is free software: you can
 # redistribute it and/or modify it under the terms of the GNU Lesser
 # General Public License as published by the Free Software Foundation,
@@ -57,19 +57,19 @@ my @ops = sort { $a->[0] cmp $b->[0] }
 
 say <<'END_OF_PREAMBLE';
 /*
- * Copyright 2018 Jeffrey Kegler
- * This file is part of Libmarpa.  Libmarpa is free software: you can
+ * Copyright 2022 Jeffrey Kegler
+ * This file is part of Marpa::R2.  Marpa::R2 is free software: you can
  * redistribute it and/or modify it under the terms of the GNU Lesser
  * General Public License as published by the Free Software Foundation,
  * either version 3 of the License, or (at your option) any later version.
  *
- * Libmarpa is distributed in the hope that it will be useful,
+ * Marpa::R2 is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser
- * General Public License along with Libmarpa.  If not, see
+ * General Public License along with Marpa::R2.  If not, see
  * http://www.gnu.org/licenses/.
  */
 
